@@ -2,6 +2,7 @@
 #include "settingsdialog.h"
 #include "aboutdialog.h"
 #include "settings.h"
+#include "networkaccessmanagerfactory.h"
 
 #include "qmlapplicationviewer.h"
 
@@ -9,7 +10,9 @@
 
 #include <QMenuBar>
 #include <QDeclarativeContext>
+#include <QDeclarativeEngine>
 #include <QProcess>
+#include <QDebug>
 
 #ifdef Q_WS_MAEMO_5
     #include <QtGui/QX11Info>
@@ -24,6 +27,11 @@ MainWindow::MainWindow(QWidget *parent) :
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+
+    QDBusConnection::systemBus().connect(QString(), "/com/nokia/csd/call", "com.nokia.csd.Call", "Coming", this, SLOT(callEvent(QDBusObjectPath,QString)));
+    QDBusConnection::systemBus().connect(QString(), "/com/nokia/csd/call", "com.nokia.csd.Call", "Created", this, SLOT(callEvent(QDBusObjectPath,QString)));
+
+    grabZoomKeys(true);
 #endif
 
     viewer = new QmlApplicationViewer;
@@ -47,14 +55,15 @@ MainWindow::MainWindow(QWidget *parent) :
     viewer->rootContext()->setContextProperty("xbmc", Xbmc::instance());
     viewer->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     viewer->setMainQmlFile(QLatin1String("qml/xbmcremote/fremantle/main.qml"));
-
-    grabZoomKeys(true);
+    viewer->engine()->setNetworkAccessManagerFactory(new NetworkAccessManagerFactory());
 
 }
 
 MainWindow::~MainWindow()
 {
+#ifdef Q_WS_MAEMO_5
     grabZoomKeys(false);
+#endif
 }
 
 void MainWindow::openSettingsDialog()
@@ -71,35 +80,22 @@ void MainWindow::openAboutDialog()
 
 void MainWindow::keyPressEvent(QKeyEvent *event)
 {
-    Settings settings;
     switch (event->key()) {
     case Qt::Key_F7:
-        if(!settings.volumeUpCommand().isEmpty()) {
-            QProcess p;
-            p.execute(settings.volumeUpCommand());
-        } else {
-            Xbmc::instance()->setVolume(Xbmc::instance()->volume() + 5);
-        }
+        Xbmc::instance()->setVolume(Xbmc::instance()->volume() + 5);
         event->accept();
         break;
 
     case Qt::Key_F8:
-        if(!settings.volumeDownCommand().isEmpty()) {
-            QProcess p;
-            p.execute(settings.volumeDownCommand());
-        } else {
-            Xbmc::instance()->setVolume(Xbmc::instance()->volume() - 5);
-        }
+        Xbmc::instance()->setVolume(Xbmc::instance()->volume() - 5);
         event->accept();
         break;
     }
     QWidget::keyPressEvent(event);
 }
 
+#ifdef Q_WS_MAEMO_5
 void MainWindow::grabZoomKeys(bool grab) {
-#ifndef Q_WS_MAEMO_5
-    Q_UNUSED(grab)
-#else
     if (!winId()) {
         qWarning("Can't grab keys unless we have a window id");
         return;
@@ -121,5 +117,19 @@ void MainWindow::grabZoomKeys(bool grab) {
              PropModeReplace,
              reinterpret_cast<unsigned char *>(&val),
              1);
+}
+
+void MainWindow::callEvent(const QDBusObjectPath &param1, const QString &param2)
+{
+    qDebug() << "phone call event" << param1.path() << param2;
+    Xbmc::instance()->dimVolumeTo(0);
+
+    QDBusConnection::systemBus().connect(QString(), param1.path(), "com.nokia.csd.Call.Instance", "Terminated", this, SLOT(callTerminated()));
+
+}
+
+void MainWindow::callTerminated()
+{
+    Xbmc::instance()->restoreVolume();
+}
 #endif
- }
