@@ -1,3 +1,21 @@
+/*****************************************************************************
+ * Copyright: 2011 Michael Zanetti <mzanetti@kde.org>                        *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 3 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ ****************************************************************************/
+
 #include "movies.h"
 #include "xbmcconnection.h"
 #include "xbmc.h"
@@ -6,7 +24,7 @@
 #include "videoplaylistitem.h"
 
 Movies::Movies(XbmcModel *parent) :
-    XbmcModel(parent)
+    XbmcLibrary(parent)
 {
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
     m_request = XbmcConnection::sendCommand("VideoLibrary.GetMovies");
@@ -70,7 +88,7 @@ void Movies::playItem(int index)
     Xbmc::instance()->videoPlayer()->playlist()->clear();
     VideoPlaylistItem item(m_list.at(index)->data(RoleMovieId).toInt());
     Xbmc::instance()->videoPlayer()->playlist()->addItems(item);
-    Xbmc::instance()->videoPlayer()->playlist()->playItem(0);
+    Xbmc::instance()->videoPlayer()->playItem(0);
 }
 
 void Movies::addToPlaylist(int row)
