@@ -21,6 +21,7 @@
 
 #include <QObject>
 #include <QVariantMap>
+#include <QPropertyAnimation>
 
 class XbmcModel;
 class AudioLibrary;
@@ -29,6 +30,7 @@ class VideoLibrary;
 class Player;
 class AudioPlayer;
 class VideoPlayer;
+class PicturePlayer;
 class Shares;
 
 class Keys;
@@ -40,8 +42,11 @@ class Xbmc : public QObject
     Q_PROPERTY(QString connectionError READ connectionError NOTIFY connectedChanged)
     Q_PROPERTY(QString hostname READ hostname WRITE setHostname NOTIFY hostnameChanged)
     Q_PROPERTY(int port READ port WRITE setPort NOTIFY portChanged)
+    Q_PROPERTY(QString username READ username WRITE setUsername)
+    Q_PROPERTY(QString password READ password WRITE setPassword)
     Q_PROPERTY(QString vfsPath READ vfsPath NOTIFY vfsPathChanged)
     Q_PROPERTY(Player* activePlayer READ activePlayer NOTIFY activePlayerChanged)
+    Q_PROPERTY(bool picturePlayerActive READ picturePlayerActive NOTIFY picturePlayerActiveChanged)
     Q_PROPERTY(QString state READ state NOTIFY stateChanged)
     Q_PROPERTY(int volume READ volume WRITE setVolume NOTIFY volumeChanged)
 
@@ -56,7 +61,9 @@ public:
 
     Q_INVOKABLE AudioPlayer *audioPlayer();
     Q_INVOKABLE VideoPlayer *videoPlayer();
+    Q_INVOKABLE PicturePlayer *picturePlayer();
     Q_INVOKABLE Player *activePlayer();
+    Q_INVOKABLE bool picturePlayerActive();
 
     Q_INVOKABLE Keys *keys();
 
@@ -68,6 +75,10 @@ public:
     void setHostname(const QString &hostname);
     int port();
     void setPort(int port);
+    QString username();
+    void setUsername(const QString &username);
+    QString password();
+    void setPassword(const QString &password);
 
     QString state();
 
@@ -76,8 +87,12 @@ public:
     Q_INVOKABLE void setVolume(int volume);
     int volume();
 
+    Q_INVOKABLE void dimVolumeTo(int newVolume);
+    Q_INVOKABLE void restoreVolume();
+
 public slots:
     void quit();
+    void queryActivePlayers();
 
 signals:
     void connectedChanged(bool connected);
@@ -87,6 +102,9 @@ signals:
     void stateChanged();
     void hostnameChanged();
     void portChanged();
+    void usernameChanged();
+    void passwordChanged();
+    void picturePlayerActiveChanged();
 
 private slots:
     void parseAnnouncement(const QVariantMap &map);
@@ -106,7 +124,9 @@ private:
 
     AudioPlayer *m_audioPlayer;
     VideoPlayer *m_videoPlayer;
+    PicturePlayer *m_picturePlayer;
     Player *m_activePlayer;
+    bool m_picturePlayerActive;
 
     Keys *m_keys;
 
@@ -115,6 +135,13 @@ private:
 
     QString m_hostname;
     int m_port;
+    QString m_username;
+    QString m_password;
+
+    int m_originalVolume;
+    int m_targetVolume;
+
+    QPropertyAnimation m_volumeAnimation;
 
 };
 
