@@ -236,10 +236,16 @@ void XbmcConnectionPrivate::replyReceived()
         xDebug(XDAREA_NETWORKDATA) << ">>> Incoming:" << rsp;
 
         if(rsp.value("id").toInt() == m_versionRequestId) {
-            m_xbmcVersion.setDate(rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(4).toInt(),
-                                  rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(6).right(2).toInt(),
-                                  rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(8).right(2).toInt());
-            xDebug(XDAREA_CONNECTION) << "Connected to XBMC version:" << m_xbmcVersion.toString(Qt::SystemLocaleLongDate);
+            // If the remote xbmc has the version field not compiled in, assume its the latest known one
+            if(rsp.value("result").toMap().value("version").toMap().value("revision").toString() == "Unknown") {
+                m_xbmcVersion.setDate(2011, 10, 8);
+                qDebug() << "WARNING: Cannot determine Xbmc version. Assuming" << m_xbmcVersion.toString(Qt::SystemLocaleLongDate);
+            } else {
+                m_xbmcVersion.setDate(rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(4).toInt(),
+                                      rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(6).right(2).toInt(),
+                                      rsp.value("result").toMap().value("version").toMap().value("revision").toString().left(8).right(2).toInt());
+                xDebug(XDAREA_CONNECTION) << "Connected to XBMC version:" << m_xbmcVersion.toString(Qt::SystemLocaleLongDate);
+            }
             if(m_xbmcVersion >= QDate(2011, 9, 23)) {
                 sendNextCommand2();
                 m_connected = true;
